timespantools.timespan_2_happens_during_timespan_1
==================================================

.. autofunction:: abjad.tools.timespantools.timespan_2_happens_during_timespan_1.timespan_2_happens_during_timespan_1
